@@ -1,6 +1,6 @@
 package Test::BDD::Cucumber;
-BEGIN {
-  $Test::BDD::Cucumber::VERSION = '0.07';
+{
+  $Test::BDD::Cucumber::VERSION = '0.08';
 }
 
 =head1 NAME
@@ -9,7 +9,7 @@ Test::BDD::Cucumber - Feature-complete Cucumber-style testing in Perl
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 DESCRIPTION
 
@@ -48,6 +48,11 @@ If you B<want to extend or integrated Test::BDD::Cucumber> then you'd probably
 be more interested in our L<Architecture
 overview|Test::BDD::Cucumber::Manual::Architecture>.
 
+=head1 TEN SECOND GUIDE TO USING THIS IN YOUR CI ENVIRONMENT
+
+Don't use the command-line tool, L<App::pherkin>. Instead, look at the L<How to integrate with
+Test::Builder|Test::BDD::Cucumber::Manual::Integration> document.
+
 =head1 BUGS, MISSING, AND LIMITATIONS
 
 The following things do not work in this release, although support is planned
@@ -55,8 +60,6 @@ in the very near future:
 
 =over 4
 
-=item * Tags
-
 =item * Localization
 
 =item * Step Argument Transforms
@@ -87,4 +90,4 @@ Copyright 2011, Peter Sergeant; Licensed under the same terms as Perl
 
 =cut
 
-1;
\ No newline at end of file
+1;
